Index: pbx.c
===================================================================
--- pbx.c	(revision 7691)
+++ pbx.c	(working copy)
@@ -1207,13 +1189,9 @@
 		return NULL;
 	}
 
-	for (acf = acf_root; acf; acf = acf->next) {
-		if (!strncasecmp(word, acf->name, wordlen)) {
-			if (++which > state) {
-				ret = strdup(acf->name);
-				break;
-			}
-		}
- 	}
+	/* case-insensitive for convenience in this 'complete' function */
+	for (acf = acf_root; acf && !ret; acf = acf->next)
+		if (!strncasecmp(word, acf->name, wordlen) && ++which > state)
+			ret = strdup(acf->name);
 
 	ast_mutex_unlock(&acflock);
@@ -1231,11 +1209,9 @@
 		return NULL;
 	}
 
-	for (acfptr = acf_root; acfptr; acfptr = acfptr->next) {
-		if (!strcmp(name, acfptr->name)) {
+	for (acfptr = acf_root; acfptr; acfptr = acfptr->next)
+		if (!strcmp(name, acfptr->name))
 			break;
-		}
-	}
 
 	ast_mutex_unlock(&acflock);
 	
@@ -2970,17 +2933,10 @@
 		return NULL;
 	}
 
-	/* ... walk all applications ... */
-	for (a = apps; a; a = a->next) {
-		/* ... check if word matches this application ... */
-		if (!strncasecmp(word, a->name, wordlen)) {
-			/* ... if this is right app serve it ... */
-			if (++which > state) {
-				ret = strdup(a->name);
-				break;
-			}
-		}
-	}
+	/* return the n-th [partial] matching entry */
+	for (a = apps; a && !ret; a = a->next)
+		if (!strncasecmp(word, a->name, wordlen) && ++which > state)
+			ret = strdup(a->name);
 
 	ast_mutex_unlock(&applock);
 
@@ -5701,26 +5657,20 @@
 const char *pbx_builtin_getvar_helper(struct ast_channel *chan, const char *name) 
 {
 	struct ast_var_t *variables;
-	struct varshead *headp;
-
+	int i;
+	struct varshead *places[2] = { NULL, &globals };
+	
+	if (!name)
+		return NULL;
 	if (chan)
-		headp=&chan->varshead;
-	else
-		headp=&globals;
+		places[0] = &chan->varshead;
 
-	if (name) {
-		AST_LIST_TRAVERSE(headp,variables,entries) {
-			if (!strcmp(name, ast_var_name(variables)))
-				return ast_var_value(variables);
-		}
-		if (headp != &globals) {
-			/* Check global variables if we haven't already */
-			headp = &globals;
-			AST_LIST_TRAVERSE(headp,variables,entries) {
+	for (i=0; i < 2; i++) {
+		if (places[i])
+			AST_LIST_TRAVERSE(places[i], variables, entries) {
 				if (!strcmp(name, ast_var_name(variables)))
 					return ast_var_value(variables);
 			}
-		}
 	}
 	return NULL;
 }
